@@ -15,6 +15,10 @@
 #include <gwenhywfar/testmodule.h>
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 
 typedef struct GWEN_TEST_FRAMEWORK GWEN_TEST_FRAMEWORK;
 
@@ -31,6 +35,11 @@ GWENHYWFAR_API GWEN_TEST_MODULE *TestFramework_GetModulesRoot(const GWEN_TEST_FR
 GWENHYWFAR_API void TestFramework_free(GWEN_TEST_FRAMEWORK *tf);
 
 
+#ifdef __cplusplus
+}
+#endif
+
+
 
 #endif
 
